<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        :paramArr="type"
        ref="customerOrderTable"
      >
        <template #toolbar>
          <el-button
            v-if="permissions.customerorder_push_otc"
            style="margin-left:10px;"
            type="primary"
            @click="pushOtc"
            >推送OTC</el-button
          >
        </template>
      </ttable>

      <!-- 弹窗, 日期选择 -->
      <ConfirmPullCustomerorder
        v-if="showPullCustomerOrderVisible"
        ref="confirmPullCustomerorder"
        @refreshDataList="getData"
      ></ConfirmPullCustomerorder>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import ConfirmPullCustomerorder from './confirm-pull-customerorder'
import TableForm from './share-customerorder-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { pushotc } from '../../../api/plan/customerorder'
import { customerOrderForJointStockCompany } from '../../../api/plan/customerorderforJointstockcompany'
import { remote } from '@/api/admin/dict'

export default {
  data() {
    return {
      stateTagArr: [
        {
          label: '标记零件待选',
          command: '01partUnCheck',
          disabled: false,
          permitArr: []
        },
        {
          label: '标记工艺文件待选',
          command: '02technologyUnCheck',
          disabled: false,
          permitArr: []
        },
        {
          label: '标记待计划',
          command: '03plan',
          disabled: false,
          permitArr: []
        },
        {
          label: '标记已下发',
          command: '04planed',
          disabled: false,
          permitArr: []
        },
        {
          label: '标记已作废',
          command: '05cancel',
          disabled: false,
          permitArr: []
        }
      ],

      ajaxFun: customerOrderForJointStockCompany,
      events: '',
      type: [1],
      currentRow: null,
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮H
        isSearch: true, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '100',
            width: '100px',
            prop: 'customerOrderNo',
            label: '订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          {
            minWidth: '120',
            prop: 'customerNo',
            label: '客户编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'customerName',
            label: '客户名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'coState',
            label: '销售订单状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getCustomerCoState,
            optList: () => {
              return this.coStateList
            }
          },
          {
            minWidth: '120',
            prop: 'isAudit',
            label: '审核状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getIsAudit,
            optList: () => {
              return this.isAuditList
            }
          },
          {
            minWidth: '120',
            prop: 'coLineNo',
            label: 'GSM行号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'otcLineNo',
            label: 'OTC行号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 状态
          {
            minWidth: '120',
            prop: 'otcPartSync',
            label: 'OTC推送状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getOtcPartSyncOptionList()
            },
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue == null) {
                formatVal = ''
              } else if (cellValue) {
                formatVal = '已同步'
              } else {
                formatVal = '未同步'
              }
              return formatVal
            }
          },
          {
            minWidth: '120',
            width: '100px',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            width: '100px',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            width: '100px',
            prop: 'docNumber',
            label: '工艺文件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            width: '100px',
            prop: 'outerColor',
            label: '外护颜色',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'otcQuantity',
            label: '销售数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'otcUnit',
            label: '销售单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'buyQtyDue',
            label: '库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'unit',
            label: '零件单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'requireNumber',
            label: '已下发数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'customerPartSpec',
            label: '客户零件规格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'division',
            label: '事业部',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'printType',
            label: '印字方式',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'printingRequirements',
            label: '印字要求',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'packageRequire',
            label: '包装要求',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'qualityRequire',
            label: '质量要求',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'otherProductRequire',
            label: '生产需求说明',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'divisionSystem',
            label: '系统',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'shippingAddress',
            label: '收货地址',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'salesmanName',
            label: '业务员',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'lengthRequirement',
            label: '盘长要求',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'ifsLineNo',
            label: 'IFS行号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'ifsDeliveryNo',
            label: 'IFS交货号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'ifsLineItemNo',
            label: 'IFS行项号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'salesPartNo',
            label: '销售件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'salesPartName',
            label: '销售件描述',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            width: '120',
            prop: 'wantedDeliveryDate',
            label: '期望交货时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          },
          {
            minWidth: '200',
            width: '120',
            prop: 'plannedDeliveryDate',
            label: '计划交货时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          },
          {
            minWidth: '120',
            prop: 'manufactureAttr',
            label: '制造属性',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getManufactureAttr,
            optList: () => {
              return this.manufactureAttrs
            }
          },
          {
            minWidth: '200',
            width: '120',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          }
        ],
        toolbar: [],
        operator: null
      },
      addOrUpdateVisible: false,
      coStateList: [
        {
          value: '01partUnCheck',
          label: '零件待选'
        },
        {
          value: '02technologyUnCheck',
          label: '工艺文件待选'
        },
        {
          value: '03plan',
          label: '待计划'
        },
        {
          value: '04planed',
          label: '已下发'
        },
        {
          value: '05cancel',
          label: '已作废'
        }
      ],
      isAuditList: [
        {
          value: '01draft',
          label: '草稿'
        },
        {
          value: '02pending',
          label: '审核中'
        },
        {
          value: '03accepted',
          label: '通过'
        },
        {
          value: '04reject',
          label: '退回'
        }
      ],
      partName: null,
      showPullCustomerOrderVisible: false,
      manufactureAttrs: [],
      otcPartSyncOptionList: [
        {
          value: true,
          label: '已同步'
        },
        {
          value: false,
          label: '未同步'
        }
      ]
    }
  },
  components: {
    ttable,
    TableForm,
    ConfirmPullCustomerorder
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  mounted() {},
  created() {
    this.getManufactureAttrs()

    if (this.permissions.customerorder_from_otc) {
      this.table.toolbar.push({
        text: '获取股份销售订单',
        type: 'primary',
        fun: this.pullCustomerOrder,
        disabled: false,
        permitArr: []
      })
    }
  },
  methods: {
    getOtcPartSyncOptionList() {
      return this.otcPartSyncOptionList
    },
    getData() {
      this.$refs.customerOrderTable.getDataList()
    },
    formatDutyDate(row, column, cellValue) {
      if (cellValue) {
        const dutyDateList = /\d{4}-\d{1,2}-\d{1,2}/g.exec(cellValue)
        if (dutyDateList && dutyDateList.length > 0) {
          return dutyDateList[0]
        }
      }
      return ''
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row ? row.id : row)
      })
    },
    // 打开日期选择框
    pullCustomerOrder() {
      this.showPullCustomerOrderVisible = true
      this.$nextTick(() => {
        this.$refs.confirmPullCustomerorder.init()
      })
    },
    judgeCoState(mulSelection) {
      let stateFlag = true
      mulSelection.forEach((item) => {
        if (item.coState === '05cancel') {
          stateFlag = false
        }
      })
      return stateFlag
    },
    // table自带事件
    handleSelectionChange(val) {
      // 根据状态，禁用表头按钮
      // 筛选出选中记录的状态
      var stateArr = val.map(function(value, index) {
        return value.coState
      })
      // 选中状态数组元素去重
      var uniqueStateArr = []
      for (var i = 0; i < stateArr.length; i++) {
        if (uniqueStateArr.indexOf(stateArr[i]) == -1) {
          uniqueStateArr.push(stateArr[i])
        }
      }
      // 循环自定义按钮，判断每个按钮的permitArr是否完全包含选中状态，若完全包含，则按钮亮，否则按钮灰
      for (var i = 0; i < this.stateTagArr.length; i++) {
        if (
          uniqueStateArr.every((val) =>
            this.stateTagArr[i].permitArr.length <= 0
              ? true
              : this.stateTagArr[i].permitArr.includes(val)
          )
        ) {
          this.stateTagArr[i].disabled = false
        } else {
          this.stateTagArr[i].disabled = true
        }
      }
      this.multipleSelection = val
    },
    getCustomerCoState(row, column, cellValue) {
      this.coStateList.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getManufactureAttr(row, column, cellValue) {
      this.manufactureAttrs.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getManufactureAttrs() {
      remote('manufacture_attr_type').then((response) => {
        if (response.data.code === 0) {
          this.manufactureAttrs = response.data.data
        } else {
          this.manufactureAttrs = []
        }
      })
    },
    getIsAudit(row, column, cellValue) {
      this.isAuditList.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    pushOtc() {
      if (this.judgeCoState(this.multipleSelection)) {
        const ids = []
        this.multipleSelection.forEach((item) => {
          ids.push(item.id)
        })
        pushotc(ids, { pathCode: '1' }).then((response) => {
          const resData = response.data
          if (resData.code === 0) {
            this.$message.success('成功')
            this.getData()
          } else {
            this.$message.error('失败')
          }
        })
      } else {
        this.$message.error('销售订单审核状态为作废，不可进行操作！')
      }
    }
  }
}
</script>
